Install
=======

You can install Neads via :code:`pip`::

    $ pip install neads

Then you may use the tutorials_ to help you with the first steps.

.. _tutorials: https://www.cs.cas.cz/hartman/neads/doc/html/tutorials/index.html